﻿using System;
using System.Linq;
using SettingsReader.App.Models;
using SettingsReader.App.Settings;

namespace SettingsReader.App.Services
{
    public interface IUserService
    {
        User Register(string email, string password);
    }

    public class UserService : IUserService
    {
        private readonly IDatabase _database;
        private readonly UserSettings _userSettings;

        public UserService(IDatabase database, UserSettings userSettings)
        {
            _database = database;
            _userSettings = userSettings;
        }

        public User Register(string email, string password)
        {
            _database.OpenConnection();
            var userExists = _database
                .GetAllUsers()
                .Any(x => x.Email.Equals(email, StringComparison.InvariantCultureIgnoreCase));

            if (userExists)
                throw new Exception($"User with email: '{email}' already exists.");

            var user = new User(email, _userSettings.DefaultUsername, password, _userSettings.ActiveByDefault);
            _database.SaveUser(user);

            return user;
        }
    }
}